﻿namespace Kreta.Framework
{
    /// <summary>
    /// Naplózható események felsorolása.
    /// </summary>
    public enum Events
    {
        /// <summary>
        /// Általános vagy ismeretlen esemény.
        /// </summary>
        /// <remarks>Akkor használjuk, amikor nincs megfelelő típus ebben a felsorolásban.</remarks>
        GENERAL = 0,

        /// <summary>
        /// Nem programozó által kiváltott kivétel
        /// </summary>
        SYSTEM_EXCEPTION = 1000,

        /// <summary>
        /// Olyan kivétel ami rendkívül súlyos
        /// </summary>
        CRITICAL_EXCEPTION = 1001,

        /// <summary>
        /// Olyan kivétel ami az SDA.DataProvider-től származik
        /// </summary>
        DATAPROVIDER_EXCEPTION = 1002,

        /// <summary>
        /// Jobütemező kivétele
        /// </summary>
        SCHEDULER_EXCEPTION = 1003,

        /// <summary>
        /// Tárolt hívó kivétel
        /// </summary>
        PROGRAMMABILITY_EXCEPTION = 1004,

        /// <summary>
        /// Szabolcs féle adatbázis státusz riport a rendelkezésre álló helyről
        /// </summary>
        DB_TABLESPACE_WARNING = 2000,

        LICENSE_SUCCESS = 3000,
        LICENSE_ERROR = 3001,
        LICENSE_WARNING = 3002,

        UPDATE_INFO = 4000,
        UPDATE_ERROR = 4001,

        WEB_ERROR_REPORT = 5000,

        #region Keretrendszer események
        /// <summary>
        /// Általános keretrendszer esemény.
        /// </summary>
        FRAMEWORK_GENERAL = 10001,

        /// <summary>
        /// Érvénytelen konfiguráció
        /// </summary>
        FRAMEWORK_CONFIG_INVALIDCONFIG = 10002,

        /// <summary>
        /// Általános keretrendszeri adatbázishiba.
        /// </summary>
        FRAMEWORK_DB_GENERAL = 10003,

        /// <summary>
        /// Adatbázis-kiszolgáló nem található.
        /// </summary>
        FRAMEWORK_DB_SERVERNOTFOUND = 10004,

        /// <summary>
        /// Általános munkamenet-hiba.
        /// </summary>
        FRAMEWORK_SESSION_GENERAL = 10005,

        /// <summary>
        /// Munkamenet nem hozható létre.
        /// </summary>
        FRAMEWORK_SESSION_CANNOTCREATE = 10006,

        /// <summary>
        /// Érvénytelen munkamenet.
        /// </summary>
        FRAMEWORK_SESSION_INVALID = 10007,

        /// <summary>
        /// A munkamenet-kezelő nem tudott elindulni.
        /// </summary>
        FRAMEWORK_SESSION_CANNOTSTART = 10008,

        /// <summary>
        /// A munkement-kezelő nem tudott leállni.
        /// </summary>
        FRAMEWORK_SESSION_CANNOTSTOP = 10009,

        /// <summary>
        /// Felhasználói kontextus nem hozható létre.
        /// </summary>
        FRAMEWORK_USERCONTEXT_CANNOTCREATE = 10010,

        /// <summary>
        /// Felhasználói kontextus érvénytelen.
        /// </summary>
        FRAMEWORK_USERCONTEXT_INVALID = 10011,

        /// <summary>
        /// A kiszolgáló elindult
        /// </summary>
        FRAMEWORK_SERVERSTART = 10012,

        /// <summary>
        /// A kiszolgáló leállt.
        /// </summary>
        FRAMEWORK_SERVERSTOP = 10013,

        /// <summary>
        /// A kiszolgáló betöltötte a konfigurációt.
        /// </summary>
        FRAMEWORK_CONFIGLOADED = 10014,

        /// <summary>
        /// Munkamenet létrehozás.
        /// </summary>
        FRAMEWORK_SESSIONCREATED = 10015,

        /// <summary>
        /// Munkamenet törlés.
        /// </summary>
        FRAMEWORK_SESSIONDELETED = 10016,

        /// <summary>
        /// Munkamenet elévülés.
        /// </summary>
        FRAMEWORK_SESSIONEXPIRED = 10017,

        /// <summary>
        /// Kivétel történt.
        /// </summary>
        FRAMEWORK_EXCEPTION = 10018,

        /// <summary>
        /// Entitás előélet mentése sikertelen.
        /// </summary>
        FRAMEWORK_ENTITYHISTORYFAILED = 10019,

        /// <summary>
        /// Tranzakció kezdeményezése.
        /// </summary>
        FRAMEWORK_BEGINTRANSACTION = 10020,

        /// <summary>
        /// Tranzakció jóváhagyás.
        /// </summary>
        FRAMEWORK_COMMITTRANSACTION = 10021,

        /// <summary>
        /// Tranzakció visszagörgetés.
        /// </summary>
        FRAMEWORK_ROLLBACKTRANSACTION = 10022,

        /// <summary>
        /// Kiszolgáló terheltsége.
        /// </summary>
        FRAMEWORK_SERVERLOAD = 10023,

        /// <summary>
        /// A kiszolgáló munkameneteinek törlése.
        /// </summary>
        FRAMEWORK_SESSIONCLEANUP = 10024,

        /// <summary>
        /// Sikertelen naplózás.
        /// </summary>
        FRAMEWORK_LOGFAILED = 10025,

        /// <summary>
        /// Sérült adat integritás.
        /// </summary>
        FRAMEWORK_DATAINTEGRITYVIOLATION = 10026,

        /// <summary>
        /// Hivatkozás nemlétező tranzakcióra.
        /// </summary>
        FRAMEWORK_NOTINTRANSACTION = 10027,

        /// <summary>
        /// Munkement korlát elérése.
        /// </summary>
        FRAMEWORK_SESSIONLIMITREACHED = 10028,

        /// <summary>
        /// Külső kulcs megsértése.
        /// </summary>
        FRAMEWORK_DB_FOREIGNKEYVIOLATION = 10029,

        /// <summary>
        /// Egyediség megsérétse.
        /// </summary>
        FRAMEWORK_DB_UNIQUEKEYVIOLATION = 10030,

        /// <summary>
        /// Leállítási kérelem (regisztrált szerver esetén)
        /// </summary>
        FRAMEWORK_SERVER_STOPPING = 10031,

        /// <summary>
        /// Érvényes felhasználói belépés
        /// </summary>
        FRAMEWORK_USER_LOGIN = 10033,

        /// <summary>
        /// Felhasználó szerepkörválasztás
        /// </summary>
        FRAMEWORK_USER_SETROLE = 10034,

        /// <summary>
        /// Deadlock.
        /// </summary>
        FRAMEWORK_DB_DEADLOCK = 10035,
        #endregion

        #region Akciókkal kapcsolatos események

        /// <summary>
        /// Általános vagy ismeretlen, akcióval kapcsolatos esemény.
        /// </summary>
        ACTION_GENERAL = 20001,

        /// <summary>
        /// Érvénytelen kérés
        /// </summary>
        ACTION_INVALIDREQUEST = 20002,

        /// <summary>
        /// Befejezetlen művelet.
        /// </summary>
        ACTION_INCOMPLETED = 20003,

        /// <summary>
        /// Nem létező művelet.
        /// </summary>
        ACTION_NOTFOUND = 20004,

        /// <summary>
        /// Akció futtatás
        /// </summary>
        ACTION_EXECUTE = 20005,

        /// <summary>
        /// Érvénytelen mező hossz
        /// </summary>
        ACTION_INVALID_FIELD_LENGTH = 20006,

        #endregion

        #region WindowsService

        /// <summary>
        /// Windows service / Pharos sikeres hívás
        /// </summary>
        WINDOWSSERVICEEXECUTE = 21000,

        /// <summary>
        /// Windows service / Pharos hiba
        /// </summary>
        WINDOWSSERVICEERROR = 21001,

        #endregion

        #region Entitásokkal kapcsolatos események

        /// <summary>
        /// Általános entitás esemény.
        /// </summary>
        ENTITY_GENERAL = 30001,

        /// <summary>
        /// Entitás nem található.
        /// </summary>
        ENTITY_NOTFOUND = 30002,

        /// <summary>
        /// Érvénytelen adat.
        /// </summary>
        ENTITY_INVALIDDATA = 30003,

        /// <summary>
        /// Érvénytelen entitás állapot.
        /// </summary>
        ENTITY_INVALIDSTATE = 30004,
        ENTITY_LOAD = 30005,
        ENTITY_INSERT = 30006,
        ENTITY_UPDATE = 30007,
        ENTITY_DELETE = 30008,
        ENTITY_MODIFY = 30009,

        /// <summary>
        /// Érvénytelen entitásverzió.
        /// </summary>
        ENTITY_EXPIREDVERSION = 30010,

        /// <summary>
        /// Csak olvasható mezőre történt írási kísérlet.
        /// </summary>
        ENTITY_READONLYATTRIBUTE = 30011,

        /// <summary>
        /// Az entitás törlése sikertelen, mert vannak kapcsolódásai.
        /// </summary>
        ENTITY_DELETEFAILED = 30012,

        /// <summary>
        /// Az entitás törlése sikertelen, mert vannak kapcsolódásai.
        /// </summary>
        ENTITY_READONLY = 30013,

        ENTITY_INVALIDXML = ACTION_INVALIDREQUEST,

        #endregion

        #region Jogosultságrendszerrel kapcsolatos események

        /// <summary>
        /// Általános jogosultságrendszer esemény.
        /// </summary>
        SECURITY_GENERAL = 40001,

        /// <summary>
        /// Írás jogosultság megsértése.
        /// </summary>
        SECURITY_WRITE = 40002,

        /// <summary>
        /// Érvénytelen művelet.
        /// </summary>
        SECURITY_INVALIDOPERATION = 40003,

        /// <summary>
        /// Sikertelen bejelentkezési kísérlet.
        /// </summary>
        SECURITY_LOGINFAILED = 40004,

        /// <summary>
        /// Érvénytelen szerepkör.
        /// </summary>
        SECURITY_INVALIDROLE = 40005,

        /// <summary>
        /// Oszlopjogosultság megsértése.
        /// </summary>
        SECURITY_COLUMNVIOLATION = 40006,

        /// <summary>
        /// Belépési követelmények nem teljesülése.
        /// </summary>
        SECURITY_LOGINREQUIREMENTFAILED = 40007,

        /// <summary>
        /// Érvénytelen helyettesített szemény.
        /// </summary>
        SECURITY_INVALIDSUBEMPLOYEEID = 40008,

        /// <summary>
        /// Abban az esetben dobjuk ezt az exceptiont, ha olyan szerepkörrel próbál meg jogosultságot kiosztani,
        /// aminek nincs prioritása.
        /// </summary>
        SECURITY_INVALIDPRIORITY = 40009,

        /// <summary>
        /// Active directory-val kapcsolatos hibák
        /// </summary>
        SECURITY_ACTIVEDIRECTORY = 40010,

        /// <summary>
        /// Hibás Active Directory login/jelszó
        /// </summary>
        SECURITY_ACTIVEDIRECTORY_LOGINFAILED = 40011,

        #endregion

        #region SQL-lel kapcsolatos események

        /// <summary>
        /// Általános SQL esemény.
        /// </summary>
        SQL_GENERAL = 50001,

        /// <summary>
        /// SQL futtatása.
        /// </summary>
        SQL_EXECUTED = 50002,

        #endregion

        /// <summary>
        /// Általános Neptun üzleti logkai esemény.
        /// </summary>
        NEPTUN_GENERAL = 60000,

        #region Poszeidon

        /// <summary>
        /// Általános Poszeidon üzleti logkai esemény.
        /// </summary>
        POSZEIDON_GENERAL = 65000,

        ///// <summary>
        ///// A meghívott fájlszerver nem áll rendelkezésre.
        ///// </summary>
        FAJLSZERVER_REQUESTEDFILESERVERINACTIVE = 65004,

        /// <summary>
        /// Minden neptunos behívást erre a kódra naplózunk.
        /// </summary>
        NEPTUN_CONNECTOR_EVENT = 65010,

        /// <summary>
        /// Ha egy neptunos behívásnál hiba történik.
        /// </summary>
        NEPTUN_CONNECTOR_ERROR = 65011,

        /// <summary>
        /// Moreq2 import hiba.
        /// </summary>
        MOREQ2_IMPORT = 65012,

        /// <summary>
        /// Moreq2 esemény.
        /// </summary>
        MOREQ2 = 65013,

        /// <summary>
        /// Az alapértelmezett EntityHistoryMode változásának eseménye.
        /// </summary>
        ENTITYHISTORYMODE = 65014,

        /// <summary>
        /// A lapolvasónál dobott warningtípus.
        /// </summary>
        SCANNER_ERROR = 65015,

        #endregion

        /// <summary>
        /// Általános FDL esemény.
        /// </summary>
        FDL_GENERAL = 70000,

        /// <summary>
        /// Érvénytelen FDL szűrő.
        /// </summary>
        FDL_BAD_FILTER = 70001,

        /// <summary>
        /// Egyéb esemény.
        /// </summary>
        CUSTOM_HANDLABLE = 80000,

        /// <summary>
        /// Fejlesztő által feldobott esemény, az általa megadott szöveggel
        /// </summary>
        DEVELOPER_DEFINIED = 80001,

        /// <summary>
        /// SMS általános log esemény
        /// </summary>
        SMS_GENERAL = 81000,

        /// <summary>
        /// EMAIL általános log esemény
        /// </summary>
        EMAIL_GENERAL = 82000,

        /// <summary>
        /// Felhasználó (alkalmazott, hallgató) összevonásakor SQL (update, insert) utasítás generálása,
        /// amivel vissza lehet állítani a régi állapotot
        /// általános log esemény
        /// </summary>
        USER_COLLAPSE = 83000,

        /// <summary>
        /// Felhasználó (alkalmazott, hallgató) összevonásakor keletkező hibához log esemény.
        /// </summary>
        USER_COLLAPSE_ERROR = 83001,

        /// <summary>
        /// Fájl szerverrel kapcsolatos log események
        /// </summary>
        FAJLSZERVER_GENERAL = 84000,

        /// <summary>
        /// Értesítés feldolgozás általános log esemény
        /// </summary>
        MESSAGEMANAGER_GENERAL = 85000,

        /// <summary>
        /// verziófrissítés naplója
        /// </summary>
        NEPTUN_RELEASE = 90001,

        /// <summary>
        /// adatbázis összehasonlítás naplója
        /// </summary>
        NEPTUN_COMPARE = 90002,

        /// <summary>
        /// egyéb naplózást kívánó scriptek futásának naplója 
        /// </summary>
        NEPTUN_SCRIPTS = 90003,

        /// <summary>
        /// adatbázis ellenőrző scriptek erdeménye pl.(táblatér)
        /// </summary>
        NEPTUN_DBCHECK = 90004,

        /// <summary>
        /// egyéb riportok, statisztikák futásának eredményei
        /// </summary>
        NEPTUN_REPORTS = 90005,

        #region LMS

        /// <summary>
        /// LMS hiba
        /// </summary>
        LMS_ERROR = 100000,

        #endregion

        /// <summary>
        /// fir 2.0 omkod valtozas rogzitesehez
        /// </summary>
        OM_CODE_CHANGED = 110000,

        #region Kliens oldali események

        /// <summary>
        /// Kliens oldali kivétel
        /// </summary>
        CLIENT_GENERAL = 120000,

        #endregion

        /// <summary>
        /// Job ütemezés
        /// </summary>
        JOB_SCHEDULE = 130000,

        /// <summary>
        /// Job futtatás
        /// </summary>
        JOB_EXECUTE = 130001,

        #region MobileService

        /// <summary>
        /// Mobile sikeres hívás
        /// </summary>
        MOBILESERVICEEXECUTE = 140000,

        /// <summary>
        /// Mobile service hiba
        /// </summary>
        MOBILESERVICEERROR = 140001,

        #endregion

        /// <summary>
        /// fir2 diakigeny kontener feloldasanak rogzitese
        /// </summary>
        DIAKIGENY_KONTENER = 150000,

        Tanulo_KIR_Import = 160000,
        Tanar_KIR_Import = 160001,
        Tanevrend_Import = 160002,
        DiakolimpiaCsomag = 160010
    }
}
